@@ -37,7 +37,7 @@
 /* #undef CONDUIT_GIT_SHA1_ABBREV */
 /* #undef CONDUIT_GIT_TAG */
 
-#define CONDUIT_SYSTEM_TYPE "Linux-6.12.27-1-lts"
+#define CONDUIT_SYSTEM_TYPE "Linux-6.17.9-arch1-1"
 
 #define CONDUIT_CPP_COMPILER "/usr/bin/c++"
 
